<?php
require_once 'classes/ConfigFile.class.phpi';

function mk_prepare_proc ($conf, $r) 
{
    $front_xsl_path = $_SERVER["MASTERKEY_CORE"] . '/xsl/mk_front.xsl';
    if ($conf->read('gui_front_xsl'))
      $front_xsl_path = $_SERVER["MASTERKEY_GUI"] 
        . '/' . $conf->read('gui_front_xsl');

    if (! is_file($front_xsl_path))
      die("Config setting error: Front XSLT stylesheet '" 
          . $front_xsl_path . "' from setting 'gui_front_xsl'='"
          . $conf->read('gui_front_xsl') . "'not found");

    $xsl = new DOMDocument;
    $xsl->load($front_xsl_path);

    $proc = new XSLTProcessor;
    $proc->importStyleSheet($xsl);
    
    return $proc;
}

function mk_prepare_lang_doc ($conf, $r)
{
    if( isset($r["lang"]) ) {
        $lang = $r['lang'];
    } else {
        $lang = 'en';
    } 

    /* load language file */
    $xml_lang = new DOMDocument;

    $locale_path = $_SERVER["MASTERKEY_GUI"] . '/locale';
    if (!is_dir($locale_path))
      die("Locale path '" . $locale_path . "' does not exists");

    load_lang_to_doc($xml_lang, $lang, $locale_path);
    
    append_content_from_file($xml_lang, 'about', $lang, $locale_path);
    append_content_from_file($xml_lang, 'help', $lang, $locale_path);
    
    $avail_lang = get_languages($lang, $locale_path );
    append_content_from_doc($xml_lang, $avail_lang);
    append_content_from_doc($xml_lang, $conf);
    
    return $xml_lang;
}

function mk_set_default_paths ($conf)
{
    

    if( ! $conf->read('jquery_uri') )
        $conf->write('jquery_uri', '/jquery');

    if( ! $conf->read('pazpar2_uri') )
        $conf->write('pazpar2_uri', '/pazpar2');

    if( ! $conf->read('masterkey_core_uri') )
        $conf->write('masterkey_core_uri', '/masterkey-core');

    if( ! $conf->read('masterkey_auth_uri') )
        $conf->write('masterkey_auth_uri', '/masterkey-auth');

}


function get_languages ($current_lang, $dir) {
    $xml = '';

    if ( $dh = opendir($dir)) {
        while (($entry = readdir($dh)) !== false) {
            if ( preg_match('/front-(..)\.xml/', $entry, $match) ) {
                if ($match[1] == $current_lang) {
                    $selected = ' selected="true"';
                } else {
                    $selected = '';
                }
                $langfile = ' file="'.$entry.'"';
                $xml .= "<lang$selected$langfile>".$match[1]."</lang>";
            }
        }
        
        closedir($dh);
    }
    
    $xml = "<languages>" . $xml . "</languages>";
    $doc = new DOMDocument;
    $doc->loadXml($xml);
    return $doc;
}

function load_lang_to_doc ( &$xml, $langcode, $path ) 
{
    if ( preg_match('/^[a-z]{2}$/', $langcode) ) {
        $full_path = $path . '/front-' . $langcode . '.xml';

        if ( file_exists($full_path) ) {
            $xml->load($full_path);
        } else {
            die("Language: '" . $langcode . "' currently not enabled"
                . " because file '" . $full_path . "' could not be loaded");
        }
    } else {
        die('Only 2 letter language codes');
    }
}

function append_content_from_file ( &$xml, $file, $lang, $path) 
{
    $filepath = $path.'/'.$file.'-'.$lang.'.xml';
    
    if ( !file_exists($filepath) )
        die($filepath. ' is missing.');
    
    $content_doc = new DOMDocument();
    $content_doc->load($filepath);
    
    append_content_from_doc ($xml, $content_doc);
}

function append_content_from_doc (&$toXML, &$fromXML)
{
    $nodeCopy = $toXML->importNode(
                $fromXML->documentElement,
                true);

    $toXML->documentElement->appendChild($nodeCopy);
}
